==> check-mk_1.2.6p5.orig.tar.gz: src/ListColumn.h <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef ListColumn_h
#define ListColumn_h

#include "config.h"

#include "Column.h"

class ListColumn : public Column
{
public:
    ListColumn(string name, string description, int indirect_offset) :
        Column(name, description, indirect_offset) {}
    int type() { return COLTYPE_LIST; }
    virtual void *getNagiosObject(char *name) = 0;
    virtual bool isNagiosMember(void *data, void *member) = 0;
    virtual bool isEmpty(void *data) = 0;
    Filter *createFilter(int opid, char *value);
};

#endif // ListColumn_h

==> check-mk_1.2.8p16.orig.tar.gz: src/ListColumn.h <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef ListColumn_h
#define ListColumn_h

#include "config.h"  // IWYU pragma: keep
#include <string>
#include "Column.h"
class Filter;

class ListColumn : public Column {
public:
    ListColumn(std::string name, std::string description, int indirect_offset,
               int extra_offset)
        : Column(name, description, indirect_offset, extra_offset) {}
    int type() override { return COLTYPE_LIST; }
    virtual void *getNagiosObject(char *name) = 0;
    virtual bool isNagiosMember(void *data, void *member) = 0;
    virtual bool isEmpty(void *data) = 0;
    Filter *createFilter(int opid, char *value) override;
};

#endif  // ListColumn_h
